@@ -1,4 +1,4 @@
 
 from fastapi_aad_auth._base.validators.base import Validator  # noqa: F401
 from fastapi_aad_auth._base.validators.session import SessionValidator  # noqa: F401
-from fastapi_aad_auth._base.validators.token import TokenValidator  # noqa: F401
+from fastapi_aad_auth._base.validators.token import OAuthFlowType, TokenValidator  # noqa: F401
