@@ -2,7 +2,7 @@
 
 import base64
 from enum import Enum
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from authlib.jose import errors as jwt_errors, jwk, jwt
 from authlib.jose.util import extract_header
@@ -17,7 +17,7 @@ from starlette.requests import Request
 from fastapi_aad_auth._base.authenticators import SessionAuthenticator
 from fastapi_aad_auth._base.provider import Provider, ProviderConfig
 from fastapi_aad_auth._base.state import User
-from fastapi_aad_auth._base.validators import SessionValidator, TokenValidator
+from fastapi_aad_auth._base.validators import OAuthFlowType, SessionValidator, TokenValidator
 from fastapi_aad_auth.errors import ConfigurationError
 from fastapi_aad_auth.utilities import bool_from_env,  DeprecatableFieldsMixin, expand_doc, is_deprecated, list_from_env, urls
 
@@ -162,14 +162,15 @@ class AADTokenValidator(TokenValidator):
                  use_pkce: bool = True,
                  strict: bool = True,
                  client_app_ids: Optional[List[str]] = None,
-                 user_klass: type = User):
+                 user_klass: type = User,
+                 flow_type: OAuthFlowType = OAuthFlowType.authorizationCode):  # type: ignore
         """Initialise validator for AAD token based authentication."""
         authorization_url = f"https://login.microsoftonline.com/{tenant_id}/oauth2/v2.0/authorize"
         token_url = f"https://login.microsoftonline.com/{tenant_id}/oauth2/v2.0/token"
         self.key_url = f"https://login.microsoftonline.com/{tenant_id}/discovery/v2.0/keys"
         self.tenant_id = tenant_id
         super().__init__(client_id=client_id, authorizationUrl=authorization_url, tokenUrl=token_url, api_audience=api_audience, scheme_name=scheme_name,
-                         scopes=scopes, auto_error=auto_error, enabled=enabled, use_pkce=use_pkce, user_klass=user_klass)
+                         scopes=scopes, auto_error=auto_error, enabled=enabled, use_pkce=use_pkce, user_klass=user_klass, flow_type=flow_type)
         self.strict = strict
         if client_app_ids is None:
             client_app_ids = []
@@ -269,7 +270,9 @@ class AADProvider(Provider):
             domain_hint: Optional[str] = None,
             user_klass: type = User,
             oauth_base_route: str = '/oauth',
-            token_type: Union[str, TokenType] = TokenType.access):
+            token_type: Union[str, TokenType] = TokenType.access,
+            token_scopes: Optional[Dict[str, str]] = None,
+            flow_type: OAuthFlowType = OAuthFlowType.authorizationCode):  # type: ignore
         """Initialise the auth backend.
 
         Args:
@@ -288,11 +291,14 @@ class AADProvider(Provider):
             * redirect_uri: Full URI for post authentication callbacks
             * domain_hint: Hint for the domain
             * user_klass: Class to use as a user.
+            * flows: Customise the OAuth2 Flows in the OpenAPI docs
         """
         redirect_path = self._build_oauth_url(oauth_base_route, 'redirect')
+        if token_scopes is None:
+            token_scopes = {}
         token_validator = AADTokenValidator(client_id=client_id, tenant_id=tenant_id, api_audience=api_audience,
-                                            client_app_ids=client_app_ids, scopes={}, enabled=enabled, strict=strict_token,
-                                            user_klass=user_klass)
+                                            client_app_ids=client_app_ids, scopes=token_scopes, enabled=enabled, strict=strict_token,
+                                            user_klass=user_klass, flow_type=flow_type)
         session_authenticator = AADSessionAuthenticator(session_validator=session_validator, token_validator=token_validator,
                                                         client_id=client_id, tenant_id=tenant_id, redirect_path=redirect_path,
                                                         prompt=prompt, client_secret=client_secret, scopes=scopes,
@@ -324,7 +330,8 @@ class AADProvider(Provider):
                   strict_token=provider_config.strict, api_audience=provider_config.api_audience,
                   prompt=provider_config.prompt, domain_hint=provider_config.domain_hint,
                   redirect_uri=provider_config.redirect_uri, user_klass=user_klass,
-                  oauth_base_route=config.routing.oauth_base_route, token_type=provider_config.token_type)
+                  oauth_base_route=config.routing.oauth_base_route, token_type=provider_config.token_type,
+                  token_scopes=provider_config.token_scopes, flow_type=provider_config.flow_type)
         # We need to override the login and redirect etc until it is deprecated
         if hasattr(config.routing, 'login_path') and config.routing.login_path and not is_deprecated(config.routing.__fields__['login_path']):
             obj._login_url = config.routing.login_path
